# romaa.inc
# RoMAA robot model for Stage 3.1.0
# Author: Gonzalo F. Perez Paina

define romaa position
(
  # specify the size of the model
	size [0.570 0.520 0.200]

  # the romaa's center of rotation is offset from its center of area
	origin [-0.111 0 0 0]

	obstacle_return 1									# can hit things
	laser_return 1										# reflect laser beams
	ranger_return 1										# reflect sonar beams
	blobfinder_return 1								# seen by blobfinders
	fiducial_return 1									# seen as "1" fiducial finders

	# main body
	block(
		points 10
		point[0] [ 0.174 0.142 ]
		point[1] [ 0.0962 0.260 ]
		point[2] [ -0.136 0.260 ]
		point[3] [ -0.344 0.221 ]
		point[4] [ -0.396 0.109 ]

		point[5] [ -0.396 -0.109 ]
		point[6] [ -0.344 -0.221 ]
		point[7] [ -0.136 -0.260 ]
		point[8] [ 0.0962 -0.260 ]
		point[9] [ 0.174 -0.142 ]
		z [0.07 0.3]
    color "blue"
	)

	# sensors base
	block(
		points 4
		point[0] [ 0.12 0.16 ]
		point[1] [ 0.04 0.16 ]
		point[2] [ 0.04 -0.16 ]
		point[3] [ 0.12 -0.16 ]
		z [0.3 0.31]
		color "black"
	)

	# left wheel
	block(
		points 4
		point[0] [ 0.075 0.240 ]
		point[1] [ -0.075 0.240 ]
		point[2] [ -0.075 0.210 ]
		point[3] [ 0.075 0.210 ]
		z [0 0.07]
		color "black"
	)

	# right wheel
	block(
		points 4
		point[0] [ 0.075 -0.210 ]
		point[1] [ -0.075 -0.210 ]
		point[2] [ -0.075 -0.240 ]
		point[3] [ 0.075 -0.240 ]
		z [0 0.07]
		color "black"
	)

	# castor
	block(
		points 4
		point[0] [ -0.336 0.01 ]
		point[1] [ -0.396 0.01 ]
		point[2] [ -0.396 -0.01 ]
		point[3] [ -0.336 -0.01 ]
		z [0 0.07]
		color "black"
	)

  # differential-steer model
	drive "diff"
  # estimated mass in KG
	mass 35

	localization "odom"							  # odometric localization with simple error model
	#	odom_error [ 0.05 0.05 0.1 ]    # Odometry error or slip in X, Y and Theta
)

define romaa_sonar_front ranger
(
  scount 8                          # the number of transducers

  # define the pose of each transducer [xpos ypos heading]
  spose[0] [ 0.075 0.240 90 ]
  spose[1] [ 0.124 0.190 50 ]
  spose[2] [ 0.154 0.120 30 ]
  spose[3] [ 0.154 0.05 10 ]
  spose[4] [ 0.154 -0.05 -10 ]
  spose[5] [ 0.154 -0.120 -30 ]
  spose[6] [ 0.124 -0.190 -50 ]
  spose[7] [ 0.075 -0.240 -90 ]

  # define the field of view of each transducer [range_min range_max view_angle]
  #sview [0 5.0 15]
  sview [0 5.0 30]

  # define the size of each transducer [xsize ysize] in meters
  ssize [0.01 0.05]
)

define romaa_sonar_all ranger
(
  scount 16                          # the number of transducers

  # define the pose of each transducer [xpos ypos heading]
  spose[0] [ 0.075 0.240 90 ]
  spose[1] [ 0.124 0.190 50 ]
  spose[2] [ 0.154 0.120 30 ]
  spose[3] [ 0.154 0.05 10 ]
  spose[4] [ 0.154 -0.05 -10 ]
  spose[5] [ 0.154 -0.120 -30 ]
  spose[6] [ 0.124 -0.190 -50 ]
  spose[7] [ 0.075 -0.240 -90 ]
  spose[8] [ -0.324 0.200 90 ]
  spose[9] [ -0.350 0.155 130 ]
  spose[10] [ -0.376 0.109 150 ]
  spose[11] [ -0.376 0.05 170 ]
  spose[12] [ -0.376 -0.05 -170 ]
  spose[13] [ -0.376 -0.109 -150 ]
  spose[14] [ -0.350 -0.155 -130 ]
  spose[15] [ -0.324 -0.200 -90 ]

  # define the field of view of each transducer [range_min range_max view_angle]
  #sview [0 5.0 15]
  sview [0 5.0 30]

  # define the size of each transducer [xsize ysize] in meters
  ssize [0.01 0.05]
)

define romaa_front_sonar romaa
(
  # use the sonar array defined above with a small vertical offset to
  # drop the sensors into the robot body
  romaa_sonar_front( pose [0 0 -0.1 0] )
)

define romaa_sonar romaa
(
  # use the sonar array defined above with a small vertical offset to
  # drop the sensors into the robot body
  romaa_sonar_all( pose [0 0 -0.1 0] )
)

